package com.ldodds.foaf.thinlet.model;
/**
 * <p>
 * Describes a validation error, generated by a <code>Validatable</code> 
 * object. Each validation error is tied with a particular field. Ideally field 
 * names should match up to field names in the user interface, making it 
 * easy to provide feedback to the user.
 * </p>
 * <p>
 * This code is Public Domain
 * </p>
 * 
 * @author ccslrd
 */
public class ValidationError
{
	private String _field;
	private String _message;
	/**
	 * Constructs a ValidationError representing a problem with a 
	 * specific field.
	 * 
	 * @param field the name of the field
	 * @param message the error message
	 */
	public ValidationError(String field, String message)
	{
		_field = field;
		_message = message;
	}
	/**
	 * Gets the name of the field
	 */
	public String getField()
	{
		return _field;
	}
	/**
	 * Gets the error message
	 */
	public String getMessage()
	{
		return _message;
	}
	/**
	 * Returns a string representation of this error message for logging 
	 * purposes.
	 */
	public String toString()
	{
		return "[ValidationError] " + _field + ", " + _message;
	}
    
    public static ValidationError createMissingFieldError(String field)
    {
        return new ValidationError(field, "You must provide a " + field);
    }
}
